"""
Blessed Sendgrid connector for Airbyte SDK.

Auto-generated from OpenAPI specification.
"""

from .connector import SendgridConnector
from .models import (
    SendgridAuthConfig,
    SendgridReplicationConfig,
    Contact,
    ContactsList,
    ListMetadata,
    List,
    ListsListMetadata,
    ListsList,
    SegmentStatus,
    Segment,
    SegmentsList,
    Campaign,
    CampaignsListMetadata,
    CampaignsList,
    SingleSendSendTo,
    SingleSendEmailConfig,
    SingleSend,
    SingleSendsListMetadata,
    SingleSendsList,
    Template,
    TemplatesList,
    SingleSendStatsStats,
    SingleSendStats,
    SingleSendStatsListMetadata,
    SingleSendStatsList,
    Bounce,
    Block,
    SpamReport,
    InvalidEmail,
    GlobalSuppression,
    SuppressionGroup,
    SuppressionGroupMember,
    ListsListResultMeta,
    CampaignsListResultMeta,
    SinglesendsListResultMeta,
    SinglesendStatsListResultMeta,
    SendgridCheckResult,
    SendgridExecuteResult,
    SendgridExecuteResultWithMeta,
    ContactsListResult,
    ListsListResult,
    SegmentsListResult,
    CampaignsListResult,
    SinglesendsListResult,
    TemplatesListResult,
    SinglesendStatsListResult,
    BouncesListResult,
    BlocksListResult,
    SpamReportsListResult,
    InvalidEmailsListResult,
    GlobalSuppressionsListResult,
    SuppressionGroupsListResult,
    SuppressionGroupMembersListResult,
    AirbyteSearchMeta,
    AirbyteSearchResult,
    BouncesSearchData,
    BouncesSearchResult,
    BlocksSearchData,
    BlocksSearchResult,
    CampaignsSearchData,
    CampaignsSearchResult,
    ContactsSearchData,
    ContactsSearchResult,
    GlobalSuppressionsSearchData,
    GlobalSuppressionsSearchResult,
    InvalidEmailsSearchData,
    InvalidEmailsSearchResult,
    ListsSearchData,
    ListsSearchResult,
    SegmentsSearchData,
    SegmentsSearchResult,
    SinglesendStatsSearchData,
    SinglesendStatsSearchResult,
    SinglesendsSearchData,
    SinglesendsSearchResult,
    SuppressionGroupMembersSearchData,
    SuppressionGroupMembersSearchResult,
    SuppressionGroupsSearchData,
    SuppressionGroupsSearchResult,
    TemplatesSearchData,
    TemplatesSearchResult
)
from .types import (
    ContactsListParams,
    ContactsGetParams,
    ListsListParams,
    ListsGetParams,
    SegmentsListParams,
    SegmentsGetParams,
    CampaignsListParams,
    SinglesendsListParams,
    SinglesendsGetParams,
    TemplatesListParams,
    TemplatesGetParams,
    SinglesendStatsListParams,
    BouncesListParams,
    BlocksListParams,
    SpamReportsListParams,
    InvalidEmailsListParams,
    GlobalSuppressionsListParams,
    SuppressionGroupsListParams,
    SuppressionGroupsGetParams,
    SuppressionGroupMembersListParams,
    AirbyteSearchParams,
    AirbyteSortOrder,
    BouncesSearchFilter,
    BouncesSearchQuery,
    BouncesCondition,
    BlocksSearchFilter,
    BlocksSearchQuery,
    BlocksCondition,
    CampaignsSearchFilter,
    CampaignsSearchQuery,
    CampaignsCondition,
    ContactsSearchFilter,
    ContactsSearchQuery,
    ContactsCondition,
    GlobalSuppressionsSearchFilter,
    GlobalSuppressionsSearchQuery,
    GlobalSuppressionsCondition,
    InvalidEmailsSearchFilter,
    InvalidEmailsSearchQuery,
    InvalidEmailsCondition,
    ListsSearchFilter,
    ListsSearchQuery,
    ListsCondition,
    SegmentsSearchFilter,
    SegmentsSearchQuery,
    SegmentsCondition,
    SinglesendStatsSearchFilter,
    SinglesendStatsSearchQuery,
    SinglesendStatsCondition,
    SinglesendsSearchFilter,
    SinglesendsSearchQuery,
    SinglesendsCondition,
    SuppressionGroupMembersSearchFilter,
    SuppressionGroupMembersSearchQuery,
    SuppressionGroupMembersCondition,
    SuppressionGroupsSearchFilter,
    SuppressionGroupsSearchQuery,
    SuppressionGroupsCondition,
    TemplatesSearchFilter,
    TemplatesSearchQuery,
    TemplatesCondition
)
from ._vendored.connector_sdk.types import AirbyteHostedAuthConfig as AirbyteAuthConfig

__all__ = [
    "SendgridConnector",
    "AirbyteAuthConfig",
    "SendgridAuthConfig",
    "SendgridReplicationConfig",
    "Contact",
    "ContactsList",
    "ListMetadata",
    "List",
    "ListsListMetadata",
    "ListsList",
    "SegmentStatus",
    "Segment",
    "SegmentsList",
    "Campaign",
    "CampaignsListMetadata",
    "CampaignsList",
    "SingleSendSendTo",
    "SingleSendEmailConfig",
    "SingleSend",
    "SingleSendsListMetadata",
    "SingleSendsList",
    "Template",
    "TemplatesList",
    "SingleSendStatsStats",
    "SingleSendStats",
    "SingleSendStatsListMetadata",
    "SingleSendStatsList",
    "Bounce",
    "Block",
    "SpamReport",
    "InvalidEmail",
    "GlobalSuppression",
    "SuppressionGroup",
    "SuppressionGroupMember",
    "ListsListResultMeta",
    "CampaignsListResultMeta",
    "SinglesendsListResultMeta",
    "SinglesendStatsListResultMeta",
    "SendgridCheckResult",
    "SendgridExecuteResult",
    "SendgridExecuteResultWithMeta",
    "ContactsListResult",
    "ListsListResult",
    "SegmentsListResult",
    "CampaignsListResult",
    "SinglesendsListResult",
    "TemplatesListResult",
    "SinglesendStatsListResult",
    "BouncesListResult",
    "BlocksListResult",
    "SpamReportsListResult",
    "InvalidEmailsListResult",
    "GlobalSuppressionsListResult",
    "SuppressionGroupsListResult",
    "SuppressionGroupMembersListResult",
    "AirbyteSearchMeta",
    "AirbyteSearchResult",
    "BouncesSearchData",
    "BouncesSearchResult",
    "BlocksSearchData",
    "BlocksSearchResult",
    "CampaignsSearchData",
    "CampaignsSearchResult",
    "ContactsSearchData",
    "ContactsSearchResult",
    "GlobalSuppressionsSearchData",
    "GlobalSuppressionsSearchResult",
    "InvalidEmailsSearchData",
    "InvalidEmailsSearchResult",
    "ListsSearchData",
    "ListsSearchResult",
    "SegmentsSearchData",
    "SegmentsSearchResult",
    "SinglesendStatsSearchData",
    "SinglesendStatsSearchResult",
    "SinglesendsSearchData",
    "SinglesendsSearchResult",
    "SuppressionGroupMembersSearchData",
    "SuppressionGroupMembersSearchResult",
    "SuppressionGroupsSearchData",
    "SuppressionGroupsSearchResult",
    "TemplatesSearchData",
    "TemplatesSearchResult",
    "ContactsListParams",
    "ContactsGetParams",
    "ListsListParams",
    "ListsGetParams",
    "SegmentsListParams",
    "SegmentsGetParams",
    "CampaignsListParams",
    "SinglesendsListParams",
    "SinglesendsGetParams",
    "TemplatesListParams",
    "TemplatesGetParams",
    "SinglesendStatsListParams",
    "BouncesListParams",
    "BlocksListParams",
    "SpamReportsListParams",
    "InvalidEmailsListParams",
    "GlobalSuppressionsListParams",
    "SuppressionGroupsListParams",
    "SuppressionGroupsGetParams",
    "SuppressionGroupMembersListParams",
    "AirbyteSearchParams",
    "AirbyteSortOrder",
    "BouncesSearchFilter",
    "BouncesSearchQuery",
    "BouncesCondition",
    "BlocksSearchFilter",
    "BlocksSearchQuery",
    "BlocksCondition",
    "CampaignsSearchFilter",
    "CampaignsSearchQuery",
    "CampaignsCondition",
    "ContactsSearchFilter",
    "ContactsSearchQuery",
    "ContactsCondition",
    "GlobalSuppressionsSearchFilter",
    "GlobalSuppressionsSearchQuery",
    "GlobalSuppressionsCondition",
    "InvalidEmailsSearchFilter",
    "InvalidEmailsSearchQuery",
    "InvalidEmailsCondition",
    "ListsSearchFilter",
    "ListsSearchQuery",
    "ListsCondition",
    "SegmentsSearchFilter",
    "SegmentsSearchQuery",
    "SegmentsCondition",
    "SinglesendStatsSearchFilter",
    "SinglesendStatsSearchQuery",
    "SinglesendStatsCondition",
    "SinglesendsSearchFilter",
    "SinglesendsSearchQuery",
    "SinglesendsCondition",
    "SuppressionGroupMembersSearchFilter",
    "SuppressionGroupMembersSearchQuery",
    "SuppressionGroupMembersCondition",
    "SuppressionGroupsSearchFilter",
    "SuppressionGroupsSearchQuery",
    "SuppressionGroupsCondition",
    "TemplatesSearchFilter",
    "TemplatesSearchQuery",
    "TemplatesCondition",
]